@@ -4,4 +4,4 @@ use strict;
 use Config::Simple::Conf;
 use Data::Dumper;
 
-print Dumper(Config::Simple::Conf->new("example/test_inc.conf"));
+print Dumper(Config::Simple::Conf->new($ARGV[0] || "example/test_inc.conf"));
