@@ -3,10 +3,10 @@ package Config::Simple::Conf;
 
 use strict;
 # Version number - cvs automagically updated.
-our $VERSION = $1 if('$Revision: 1.3 $' =~ /: ([\d\.]+)/);
+our $VERSION = $1 if('$Revision: 1.4 $' =~ /: ([\d\.]+)/);
 
 # Revision - cvs automagically updated
-our $REVISION = '$Id: Conf.pm,v 1.3 2016/04/20 04:17:58 cfaber Exp $';
+our $REVISION = '$Id: Conf.pm,v 1.4 2016/04/24 23:09:20 cfaber Exp $';
 
 # Ruckus Global Version Number
 
@@ -162,13 +162,15 @@ sub _fileargs {
 
 			if(/^\s*?\[([^\]]+)\]\s*?$/){
 				$hd = lc $1;
-			} elsif(!$hd) {
+				next;
+			} elsif(!$hd){
 				$hd = $head || 'global';
 			}
 
 			s/^\s+//g;
 			s/\s+$//g;
 
+			# Skip blank lines and comments
 			next if(!$_ || /^#/);
 
 			# We use argv for our arguments string and thus a section named argv is disallowed.
@@ -176,31 +178,29 @@ sub _fileargs {
 				&_die("ERROR: section name [argv] is invalid and disallowed: $tfn\:$line" . ($fn ? ' included from: ' . join('-> ', @{$fn}) : undef));
 			}
 
-			if(/^([^\]]+)\s*?=(\s*?(.+?))?$/){
-				my ($k, $v) = ($1, $2);
+			my ($k, $v) = split(/=/, $_, 2);
 
-				$k =~ s/^\s+//g;
-				$k =~ s/\s+$//g;
-				$v =~ s/^\s+//g;
-				$v =~ s/\s+$//g;
+			$k =~ s/^\s+//g;
+			$k =~ s/\s+$//g;
+			$v =~ s/^\s+//g;
+			$v =~ s/\s+$//g;
 
-				if($k eq 'die'){
-					&_die("ERROR: $tfn died on line $line: $v in section [$hd] in $tfn" . ($fn ? ' included from: ' . join('-> ', @{$fn}) : undef));
-				} elsif(!$k){
-					next if !$k;
-				}
+			if($k eq 'die'){
+				&_die("ERROR: $tfn died on line $line: $v in section [$hd] in $tfn" . ($fn ? ' included from: ' . join('-> ', @{$fn}) : undef));
+			} elsif(!$k){
+				next if !$k;
+			}
 
-				if(exists $conf->{$hd}->{$k} && $conf->{$hd}->{$k} ne "\x18"){
-					if(ref($conf->{$hd}->{$k}) eq 'ARRAY'){
-						push @{ $conf->{$hd}->{$k} }, $v;
-					} else {
-						my $tmp = $conf->{$hd}->{$k};
-						delete $conf->{$hd}->{$k};
-						@{ $conf->{$hd}->{$k} } = ($tmp, $v);
-					}
+			if(exists $conf->{$hd}->{$k} && $conf->{$hd}->{$k} ne "\x18"){
+				if(ref($conf->{$hd}->{$k}) eq 'ARRAY'){
+					push @{ $conf->{$hd}->{$k} }, $v;
 				} else {
-					$conf->{$hd}->{$k} = $v;
+					my $tmp = $conf->{$hd}->{$k};
+					delete $conf->{$hd}->{$k};
+					@{ $conf->{$hd}->{$k} } = ($tmp, $v);
 				}
+			} else {
+				$conf->{$hd}->{$k} = $v;
 			}
 		}
 		close($fh);
